changeset 29180:e2cb024e88cd

(cp-make-coding-systems-for-codepage): Remove the eight-bit-graphic and eight-bit-control charsets from the list of charsets which we convert into `?'.
author Eli Zaretskii <eliz@gnu.org>
date Thu, 25 May 2000 11:00:21 +0000
parents b19b46eabcb5
children c9e140124893
files lisp/international/codepage.el
diffstat 1 files changed, 7 insertions(+), 4 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/international/codepage.el	Thu May 25 10:56:36 2000 +0000
+++ b/lisp/international/codepage.el	Thu May 25 11:00:21 2000 +0000
@@ -515,8 +515,8 @@
 	   (symbol-value decode-table) iso-name offset)))
     (define-translation-table encode-translation
       (char-table-extra-slot (symbol-value nonascii-table) 0))
     ;; For charsets other than ascii and ISO-NAME, set `?' for
     ;; one-column charsets, and some Japanese character for
     ;; wide-column charsets.  CCL encoder convert that Japanese
     ;; character to either dos-unsupported-char-glyph or "??".
     (let ((tbl (char-table-extra-slot (symbol-value nonascii-table) 0))
@@ -525,8 +525,11 @@
 			 (logand dos-unsupported-char-glyph 255)
 		       127)
 		   ??))
-	  (charsets (delq 'ascii (delq iso-name
-				       (copy-sequence charset-list))))
+	  (charsets (delq 'ascii
+			  (delq 'eight-bit-control
+				(delq 'eight-bit-graphic
+				      (delq iso-name
+					    (copy-sequence charset-list))))))
 	  (wide-column-char (make-char 'japanese-jisx0208 32 32)))
       (while charsets
 	(aset tbl (make-char (car charsets))
@@ -515,8 +515,8 @@
     (define-translation-table encode-translation
       (char-table-extra-slot (symbol-value nonascii-table) 0))
-    ;; For charsets other than ascii and ISO-NAME, set `?' for
-    ;; one-column charsets, and some Japanese character for
+    ;; For charsets other than ascii, eight-bit-* and ISO-NAME, set
+    ;; `?' for one-column charsets, and some Japanese character for
     ;; wide-column charsets.  CCL encoder convert that Japanese
     ;; character to either dos-unsupported-char-glyph or "??".